`summary.dlmap` <- 
function(object, ...)
{
  cat(" Summary of final results: \n")
  print(object$Summary)
}
 
